@@ -65,7 +65,7 @@ class ControllerException(Exception):
 
 
 @dataclass
-class ControllerSettings:  # pylint: disable=too-many-instance-attributes
+class ControllerSettings:
     """Data class that holds controller settings."""
 
     port: str
@@ -272,6 +272,7 @@ class ControllerBase(ABC):
             dotbot.lh2_position = self.dotbots[source].lh2_position
             dotbot.gps_position = self.dotbots[source].gps_position
             dotbot.waypoints = self.dotbots[source].waypoints
+            dotbot.waypoints_threshold = self.dotbots[source].waypoints_threshold
             dotbot.position_history = self.dotbots[source].position_history
             should_reload = dotbot.status != self.dotbots[source].status
         else:
@@ -330,7 +331,7 @@ class ControllerBase(ABC):
             )
 
         if (
-            payload.payload_type == PayloadType.DOTBOT_DATA
+            payload.payload_type in [PayloadType.DOTBOT_DATA, PayloadType.SAILBOT_DATA]
             and -500 <= payload.values.direction <= 500
         ):
             dotbot.direction = payload.values.direction
@@ -346,11 +347,12 @@ class ControllerBase(ABC):
                 )
             )
 
-        if payload.payload_type == PayloadType.GPS_POSITION:
-            dotbot.gps_position = DotBotGPSPosition(
+        if payload.payload_type in [PayloadType.GPS_POSITION, PayloadType.SAILBOT_DATA]:
+            new_position = DotBotGPSPosition(
                 latitude=float(payload.values.latitude) / 1e6,
                 longitude=float(payload.values.longitude) / 1e6,
             )
+            dotbot.gps_position = new_position
             if (
                 not dotbot.position_history
                 or gps_distance(dotbot.position_history[-1], new_position)
