@@ -21,6 +21,34 @@ const dotbotStatuses = ["alive", "lost", "dead"];
 const dotbotBadgeStatuses = ["success", "secondary", "danger"];
 
 
+const useKeyPress = (targetKey) => {
+  const [keyPressed, setKeyPressed] = useState(false);
+
+  const downHandler = ({ key }) => {
+    if (key === targetKey) {
+      setKeyPressed(true);
+    }
+  };
+
+  const upHandler = ({ key }) => {
+    if (key === targetKey) {
+      setKeyPressed(false);
+    }
+  };
+
+  useEffect(() => {
+    window.addEventListener("keydown", downHandler);
+    window.addEventListener("keyup", upHandler);
+    return () => {
+      window.removeEventListener("keydown", downHandler);
+      window.removeEventListener("keyup", upHandler);
+    };
+  });
+
+  return keyPressed;
+};
+
+
 const DotBotAccordionItem = (props) => {
 
   const [ expanded, setExpanded ] = useState(false);
@@ -31,6 +59,10 @@ const DotBotAccordionItem = (props) => {
     await props.refresh();
   }
 
+  const thresholdUpdate = async (event) => {
+    props.updateWaypointThreshold(props.dotbot.address, parseInt(event.target.value));
+  };
+
   let rgbColor = "rgb(0, 0, 0)"
   if (props.dotbot.rgb_led) {
     rgbColor = `rgb(${props.dotbot.rgb_led.red}, ${props.dotbot.rgb_led.green}, ${props.dotbot.rgb_led.blue})`
@@ -101,6 +133,10 @@ const DotBotAccordionItem = (props) => {
                   <button className="btn btn-primary btn-sm m-1" onClick={async () => props.applyWaypoints(props.dotbot.address, props.dotbot.application)}>Start</button>
                   <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearWaypoints(props.dotbot.address, props.dotbot.application)}>Clear</button>
                 </p>
+                <div className="mx-auto justify-content-center">
+                  <p>{`Target threshold: ${props.dotbot.waypoints_threshold}`}</p>
+                  <input type="range" min="0" max="100" defaultValue={props.dotbot.waypoints_threshold} onChange={thresholdUpdate}/>
+                </div>
               </div>
             </div>
           </>
@@ -140,6 +176,10 @@ const SailBotItem = (props) => {
     setActive(newSailValue !== 0);
   };
 
+  const thresholdUpdate = async (event) => {
+    props.updateWaypointThreshold(props.dotbot.address, parseInt(event.target.value));
+  };
+
   useInterval(async () => {
     if (rudderValue === 0 && sailValue === 0) {
       setActive(false);
@@ -205,6 +245,10 @@ const SailBotItem = (props) => {
                     <button className="btn btn-primary btn-sm m-1" onClick={async () => props.applyWaypoints(props.dotbot.address, ApplicationType.SailBot)}>Start</button>
                     <button className="btn btn-primary btn-sm m-1" onClick={async () => props.clearWaypoints(props.dotbot.address, ApplicationType.SailBot)}>Stop</button>
                   </p>
+                  <div className="mx-auto justify-content-center">
+                    <p>{`Target threshold: ${props.dotbot.waypoints_threshold}`}</p>
+                    <input type="range" min="0" max="100" defaultValue={props.dotbot.waypoints_threshold} onChange={thresholdUpdate}/>
+                </div>
                 </div>
               </div>
             </>
@@ -226,6 +270,10 @@ const DotBots = () => {
   const [ showDotBotHistory, setShowDotBotHistory ] = useState(true);
   const [ showSailBotHistory, setShowSailBotHistory ] = useState(true);
 
+  const control = useKeyPress("Control");
+  const enter = useKeyPress("Enter")
+  const backspace = useKeyPress("Backspace");
+
   const updateActive = useCallback(async (address) => {
     await apiUpdateActiveDotbotAddress(address).catch((error) => console.error(error));
     setActiveDotbot(address);
@@ -300,26 +348,28 @@ const DotBots = () => {
   }, [activeDotbot, dotbots, setDotbots]
   );
 
-  const applyWaypoints = async (address, application) => {
+  const applyWaypoints = useCallback(async (address, application) => {
     for (let idx = 0; idx < dotbots.length; idx++) {
       if (dotbots[idx].address === address) {
-        await apiUpdateWaypoints(address, application, dotbots[idx].waypoints);
+        await apiUpdateWaypoints(address, application, dotbots[idx].waypoints, dotbots[idx].waypoints_threshold);
         return;
       }
     }
-  };
+  }, [dotbots]
+  );
 
-  const clearWaypoints = async (address, application) => {
+  const clearWaypoints = useCallback(async (address, application) => {
     let dotbotsTmp = dotbots.slice();
     for (let idx = 0; idx < dotbots.length; idx++) {
       if (dotbots[idx].address === address) {
         dotbotsTmp[idx].waypoints = [];
-        await apiUpdateWaypoints(address, application, []);
+        await apiUpdateWaypoints(address, application, [], dotbotsTmp[idx].waypoints_threshold);
         setDotbots(dotbotsTmp);
         return;
       }
     }
-  };
+  }, [dotbots]
+  );
 
   const clearPositionsHistory = async (address) => {
     let dotbotsTmp = dotbots.slice();
@@ -333,6 +383,17 @@ const DotBots = () => {
     }
   };
 
+  const updateWaypointThreshold = (address, threshold) => {
+    let dotbotsTmp = dotbots.slice();
+    for (let idx = 0; idx < dotbots.length; idx++) {
+      if (dotbots[idx].address === address) {
+        dotbotsTmp[idx].waypoints_threshold = threshold;
+        setDotbots(dotbotsTmp);
+        return;
+      }
+    }
+  };
+
   const onWsOpen = () => {
     console.log('websocket opened');
     fetchDotBots();
@@ -395,7 +456,32 @@ const DotBots = () => {
     if (!dotbots) {
       fetchDotBots();
     }
-  }, [dotbots, fetchDotBots]);
+
+    if (dotbots && control && enter) {
+      if (activeDotbot !== inactiveAddress) {
+        for (let idx = 0; idx < dotbots.length; idx++) {
+          if (dotbots[idx].address === activeDotbot) {
+            applyWaypoints(activeDotbot, dotbots[idx].application);
+            break;
+          }
+        }
+      }
+    }
+    if (dotbots && control && backspace) {
+      if (activeDotbot !== inactiveAddress) {
+        for (let idx = 0; idx < dotbots.length; idx++) {
+          if (dotbots[idx].address === activeDotbot) {
+            clearWaypoints(activeDotbot, dotbots[idx].application);
+            break;
+          }
+        }
+      }
+    }
+  }, [
+    dotbots, fetchDotBots,
+    control, enter, backspace,
+    applyWaypoints, clearWaypoints, activeDotbot
+  ]);
 
   return (
     <>
@@ -435,6 +521,7 @@ const DotBots = () => {
                       applyWaypoints={applyWaypoints}
                       clearWaypoints={clearWaypoints}
                       clearPositionsHistory={clearPositionsHistory}
+                      updateWaypointThreshold={updateWaypointThreshold}
                       refresh={fetchDotBots}
                     />
                   )
@@ -487,6 +574,7 @@ const DotBots = () => {
                       applyWaypoints={applyWaypoints}
                       clearWaypoints={clearWaypoints}
                       clearPositionsHistory={clearPositionsHistory}
+                      updateWaypointThreshold={updateWaypointThreshold}
                       refresh={fetchDotBots}
                     />
                   )
