@@ -29,87 +29,6 @@ else:
 
 LH2_LIB_PATH = os.path.join(os.path.dirname(__file__), "lib", f"lh2.{LIB_EXT}")
 LH2_LIB = CDLL(LH2_LIB_PATH)
-
-POLYNOMIALS = [
-    0x0001D258,
-    0x00017E04,
-    0x0001FF6B,
-    0x00013F67,
-]
-END_BUFFERS = [
-    [
-        0x00000000000000001,
-        0b10101010110011101,
-        0b10001010101011010,
-        0b11001100100000010,
-        0b01100101100011111,
-        0b10010001101011110,
-        0b10100011001011111,
-        0b11110001010110001,
-        0b10111000110011011,
-        0b10100110100011110,
-        0b11001101100010000,
-        0b01000101110011111,
-        0b11100101011110101,
-        0b01001001110110111,
-        0b11011100110011101,
-        0b10000110101101011,
-    ],
-    [
-        0x00000000000000001,
-        0b11010000110111110,
-        0b10110111100111100,
-        0b11000010101101111,
-        0b00101110001101110,
-        0b01000011000110100,
-        0b00010001010011110,
-        0b10100101111010001,
-        0b10011000000100001,
-        0b01110011011010110,
-        0b00100011101000011,
-        0b10111011010000101,
-        0b00110010100110110,
-        0b01000111111100110,
-        0b10001101000111011,
-        0b00111100110011100,
-    ],
-    [
-        0x00000000000000001,
-        0b00011011011000100,
-        0b01011101010010110,
-        0b11001011001101010,
-        0b01110001111011010,
-        0b10110110011111010,
-        0b10110001110000001,
-        0b10001001011101001,
-        0b00000010011101011,
-        0b01100010101111011,
-        0b00111000001101111,
-        0b10101011100111000,
-        0b01111110101111111,
-        0b01000011110101010,
-        0b01001011100000011,
-        0b00010110111101110,
-    ],
-    [
-        0x00000000000000001,
-        0b11011011110010110,
-        0b11000100000001101,
-        0b11100011000010110,
-        0b00011111010001100,
-        0b11000001011110011,
-        0b10011101110001010,
-        0b00001011001111000,
-        0b00111100010000101,
-        0b01001111001010100,
-        0b01011010010110011,
-        0b11111101010001100,
-        0b00110101011011111,
-        0b01110110010101011,
-        0b00010000110100010,
-        0b00010111110101110,
-    ],
-]
 REFERENCE_POINTS_DEFAULT = [
     [-0.1, 0.1],
     [0.1, 0.1],
@@ -120,18 +39,18 @@ CALIBRATION_DIR = Path.home() / ".pydotbot"
 
 
 def _lh2_raw_data_to_counts(raw_data: Lh2RawData, func: callable) -> List[int]:
-    counts = [0] * 4
+    counts = [0] * 2
     pos_A = 0
     pos_B = 0
-    for i in range(4):
+    for i in range(2):
         index = 0
         if raw_data.locations[i].polynomial_index in [0, 1]:
             index = pos_A
             pos_A += 1
-        elif raw_data.locations[i].polynomial_index in [2, 3]:
+        elif raw_data.locations[i].polynomial_index in [0, 1]:
             index = 2 + pos_B
             pos_B += 1
-        if index > 3:
+        if index > 1:
             continue
         counts[index] = func(
             raw_data.locations[i].polynomial_index,
@@ -188,7 +107,7 @@ class LighthouseManagerState(Enum):
     Calibrated = 3
 
 
-class LighthouseManager:  # pylint: disable=too-many-instance-attributes
+class LighthouseManager:
     """Class to manage the LightHouse positionning state and workflow."""
 
     def __init__(self):
@@ -240,8 +159,8 @@ class LighthouseManager:  # pylint: disable=too-many-instance-attributes
         )
         self.calibration_points[1][index] = np.asarray(
             calculate_camera_point(
-                counts[2],
-                counts[3],
+                counts[0],
+                counts[1],
                 self.last_raw_data.locations[2].polynomial_index,
             ),
             dtype=np.float64,
@@ -334,7 +253,7 @@ class LighthouseManager:  # pylint: disable=too-many-instance-attributes
         if self.state != LighthouseManagerState.Calibrated:
             return None
 
-        if any(raw_data.locations[index].bits == 0 for index in range(4)):
+        if any(raw_data.locations[index].bits == 0 for index in range(2)):
             return None
 
         counts = lh2_raw_data_to_counts(raw_data)
@@ -344,7 +263,7 @@ class LighthouseManager:  # pylint: disable=too-many-instance-attributes
                     counts[0], counts[1], raw_data.locations[0].polynomial_index
                 ),
                 calculate_camera_point(
-                    counts[2], counts[3], raw_data.locations[2].polynomial_index
+                    counts[0], counts[1], raw_data.locations[1].polynomial_index
                 ),
             ],
             dtype=np.float64,
