@@ -11,7 +11,7 @@ from typing import List
 from dataclasses import dataclass
 
 
-PROTOCOL_VERSION = 4
+PROTOCOL_VERSION = 7
 
 
 class PayloadType(Enum):
@@ -27,7 +27,8 @@ class PayloadType(Enum):
     CONTROL_MODE = 7
     LH2_WAYPOINTS = 8
     GPS_WAYPOINTS = 9
-    INVALID_PAYLOAD = 10  # Increase each time a new payload type is added
+    SAILBOT_DATA = 10
+    INVALID_PAYLOAD = 11  # Increase each time a new payload type is added
 
 
 class ApplicationType(IntEnum):
@@ -190,8 +191,6 @@ class Lh2RawData(ProtocolData):
             [
                 Lh2RawLocation.from_bytes(bytes_[0:10]),
                 Lh2RawLocation.from_bytes(bytes_[10:20]),
-                Lh2RawLocation.from_bytes(bytes_[20:30]),
-                Lh2RawLocation.from_bytes(bytes_[30:40]),
             ]
         )
 
@@ -241,8 +240,6 @@ class DotBotData(ProtocolData):
             locations=[
                 Lh2RawLocation.from_bytes(bytes_[2:12]),
                 Lh2RawLocation.from_bytes(bytes_[12:22]),
-                Lh2RawLocation.from_bytes(bytes_[22:32]),
-                Lh2RawLocation.from_bytes(bytes_[32:42]),
             ],
         )
 
@@ -264,8 +261,33 @@ class GPSPosition(ProtocolData):
     @staticmethod
     def from_bytes(bytes_) -> ProtocolData:
         return GPSPosition(
-            int.from_bytes(bytes_[0:4], "little", signed=True),
-            int.from_bytes(bytes_[4:8], "little", signed=True),
+            latitude=int.from_bytes(bytes_[0:4], "little", signed=True),
+            longitude=int.from_bytes(bytes_[4:8], "little", signed=True),
+        )
+
+
+@dataclass
+class SailBotData(ProtocolData):
+    """Dataclass that holds direction and GPS data and heading from SailBot application."""
+
+    direction: int = 0xFFFF
+    latitude: int = 0
+    longitude: int = 0
+
+    @property
+    def fields(self) -> List[ProtocolField]:
+        return [
+            ProtocolField(self.direction, "dir.", 2, "big"),
+            ProtocolField(self.latitude, "latitude", 4, "big", True),
+            ProtocolField(self.longitude, "longitude", 4, "big", True),
+        ]
+
+    @staticmethod
+    def from_bytes(bytes_) -> ProtocolData:
+        return SailBotData(
+            direction=int.from_bytes(bytes_[0:2], "little"),
+            latitude=int.from_bytes(bytes_[2:6], "little", signed=True),
+            longitude=int.from_bytes(bytes_[6:10], "little", signed=True),
         )
 
 
@@ -303,28 +325,32 @@ class ControlMode(ProtocolData):
 class LH2Waypoints(ProtocolData):
     """Dataclass that holds a list of LH2 waypoints."""
 
+    threshold: int
     waypoints: List[LH2Location] = dataclasses.field(default_factory=lambda: [])
 
     @property
     def fields(self) -> List[ProtocolField]:
         _fields = [ProtocolField(len(self.waypoints), "len.")]
+        _fields += [ProtocolField(value=self.threshold, name="thr.", endian="little")]
         _fields += list(chain(*[waypoint.fields for waypoint in self.waypoints]))
         return _fields
 
     @staticmethod
     def from_bytes(_) -> ProtocolData:
-        return LH2Waypoints(waypoints=[])
+        return LH2Waypoints(threshold=0, waypoints=[])
 
 
 @dataclass
 class GPSWaypoints(ProtocolData):
     """Dataclass that holds a list of GPS waypoints."""
 
+    threshold: int
     waypoints: List[GPSPosition] = dataclasses.field(default_factory=lambda: [])
 
     @property
     def fields(self) -> List[ProtocolField]:
         _fields = [ProtocolField(len(self.waypoints), "len.")]
+        _fields += [ProtocolField(value=self.threshold, name="thr.", endian="little")]
         _fields += list(chain(*[waypoint.fields for waypoint in self.waypoints]))
         for field in _fields:
             field.endian = "little"
@@ -332,7 +358,7 @@ class GPSWaypoints(ProtocolData):
 
     @staticmethod
     def from_bytes(_) -> ProtocolData:
-        return GPSWaypoints(waypoints=[])
+        return GPSWaypoints(threshold=0, waypoints=[])
 
 
 @dataclass
@@ -371,7 +397,7 @@ class ProtocolPayload:
         elif payload_type == PayloadType.CMD_RGB_LED:
             values = CommandRgbLed.from_bytes(bytes_[21:25])
         elif payload_type == PayloadType.LH2_RAW_DATA:
-            values = Lh2RawData.from_bytes(bytes_[21:61])
+            values = Lh2RawData.from_bytes(bytes_[21:41])
         elif payload_type == PayloadType.LH2_LOCATION:
             values = LH2Location.from_bytes(bytes_[21:33])
         elif payload_type == PayloadType.ADVERTISEMENT:
@@ -379,7 +405,9 @@ class ProtocolPayload:
         elif payload_type == PayloadType.GPS_POSITION:
             values = GPSPosition.from_bytes(bytes_[21:29])
         elif payload_type == PayloadType.DOTBOT_DATA:
-            values = DotBotData.from_bytes(bytes_[21:63])
+            values = DotBotData.from_bytes(bytes_[21:43])
+        elif payload_type == PayloadType.SAILBOT_DATA:
+            values = SailBotData.from_bytes(bytes_[21:31])
         elif payload_type == PayloadType.CONTROL_MODE:
             values = ControlMode.from_bytes(bytes_[21:22])
         elif payload_type == PayloadType.LH2_WAYPOINTS:
